@@ -478,7 +478,9 @@ mares_iconhd_extract_dives (dc_device_t *abstract, const unsigned char data[], u
 			break;
 	}
 	if (eop < layout->rb_profile_begin || eop >= layout->rb_profile_end) {
-		ERROR (context, "Ringbuffer pointer out of range.");
+		if (eop == 0xFFFFFFFF)
+			return DC_STATUS_SUCCESS; // No dives available.
+		ERROR (context, "Ringbuffer pointer out of range (0x%08x).", eop);
 		return DC_STATUS_DATAFORMAT;
 	}
 
