@@ -222,9 +222,9 @@ static const oceanic_common_layout_t oceanic_atom1_layout = {
 	0x0000, /* cf_devinfo */
 	0x0040, /* cf_pointers */
 	0x0240, /* rb_logbook_begin */
-	0x0A40, /* rb_logbook_end */
+	0x0440, /* rb_logbook_end */
 	8, /* rb_logbook_entry_size */
-	0x0A40, /* rb_profile_begin */
+	0x0440, /* rb_profile_begin */
 	0x8000, /* rb_profile_end */
 	0, /* pt_mode_global */
 	0 /* pt_mode_logbook */
