@@ -417,7 +417,7 @@ serial_configure (serial_t *device, int baudrate, int databits, int parity, int
 	}
 
 	// Apply the new settings.
-	if (tcsetattr (device->fd, TCSANOW, &tty) != 0) {
+	if (tcsetattr (device->fd, TCSANOW, &tty) != 0 && NOPTY) {
 #if 0 // who cares
 		SYSERROR (device->context, errno);
 		return -1;
